package verticles

import org.vertx.groovy.core.Vertx
import org.vertx.groovy.core.buffer.Buffer
import org.vertx.groovy.core.eventbus.EventBus
import org.vertx.groovy.core.parsetools.RecordParser
import org.vertx.groovy.platform.Verticle
import org.vertx.java.core.json.JsonArray
import org.vertx.java.core.json.JsonObject

String mongoAddress = "vertx.mongopersistor"

def mongoConfig = [
	"address": mongoAddress,
	"host": "localhost",
	"port": 27017,
	"db_name": "measurements",
	"username": "foo",
	"password": "bar",
]

container.with {
	deployModule('io.vertx~mod-mongo-persistor~2.0.0-final', mongoConfig)
}

def instances = 1
def jsServerPort = 8898
def postServerPort = 8899

for(i in (0..instances)) {
	
	def increment = i + 1
	String instance = increment.toString()
	String client = "msg.client" + instance
	String bridge = "/bridge" + instance
	String serverStr = "msg.server" + instance

	// set in and outbound permitted addresses
	def config = ["prefix": bridge]
	
	def inboundPermitted = []
	inboundPermitted << ["address": client]

	def outboundPermitted = []
	outboundPermitted << ["address": serverStr]
	outboundPermitted << ["address": client]
	
	def server = vertx.createHttpServer()
 
	vertx.createSockJSServer(server).bridge(config, inboundPermitted, outboundPermitted)
	
	server.listen(jsServerPort)
	
	EventBus eb = vertx.eventBus
	EventBus mb = vertx.eventBus
	
	def postServer = vertx.createHttpServer()
	
	postServer.requestHandler { request ->
	
		def body = new Buffer(0)
		def status = 201
		def contentType = request.headers.get("Content-Type")
		def map = null
		def mongoMap = [
			"action": "save",
			"collection": "measurements"
		]
		
		request.bodyHandler { buffer ->

			if(contentType == 'application/json') {
				
				try {
					
					map = new JsonObject(new String(buffer.toString())).toMap()
					
				} catch(Exception e) {
					System.err.println("Exception occurred attempting to create a Json Object")
					status = 500
				}
				
				if(map) {
					
					mongoMap << ["document": map]
					
					mb.send(mongoAddress, mongoMap) {
		
						eb.send(serverStr, map)
					}
				}
			}
		}

		request.response.with {
			statusCode = status
			statusMessage = "OK"
			end()
		}

	}.listen(postServerPort)
	
	jsServerPort = jsServerPort + 2
	postServerPort = postServerPort + 2
}