#!/usr/bin/env groovy

@Grab(group='org.codehaus.groovy.modules.http-builder', module='http-builder', version='0.7' )

import groovyx.net.http.HTTPBuilder
import groovyx.net.http.RESTClient
import static groovyx.net.http.ContentType.*

class GroovyTimerTask extends TimerTask {
    Closure closure
    void run() {
        closure()
    }
}

class TimerMethods {
    static TimerTask runEvery(Timer timer, long delay, long period, Closure codeToRun) {
        TimerTask task = new GroovyTimerTask(closure: codeToRun)
        timer.schedule task, delay, period
        task
    }
}

use (TimerMethods) {
	def timer = new Timer()
	def task = timer.runEvery(1000, 1000) {
		def http = new RESTClient( 'http://localhost:8899' )
		def resp = http.post(
	        path : 'sensor',
	        contentType: JSON, 
	        requestContentType: JSON, 
	        body : [
	        	date: [
	        		'$date': System.currentTimeMillis()
	        	], 
	        	temperature: Math.abs(new Random().nextInt() % 25) + 1,
	        	conductivity: Math.abs(new Random().nextInt() % 40) + 1, 
	        	pressure: Math.abs(new Random().nextInt() % 13) + 1,
	        	oxygen: Math.abs(new Random().nextInt() % 20) + 1,
	        	salinity: Math.abs(new Random().nextInt() % 10) + 1,
	        	instrument: "56464bd78d6afef9fa89c521",
	        	lat: 47.655317,
	        	lon: -122.304938
	        ]
		)
		println "HTTP status: ${resp.statusLine}"
	}
}
